@@ -55,7 +55,7 @@ class PurchaseRequest(ModelSQL, ModelView):
     company = fields.Many2One('company.company', 'Company', required=True,
             readonly=True, domain=[
                 ('id', If(In('company', Eval('context', {})), '=', '!='),
-                    Get(Eval('context', {}), 'company', 0)),
+                    Eval('context', {}).get('company', -1)),
             ])
     origin = fields.Reference('Origin', selection='origin_get', readonly=True,
             required=True)
@@ -73,6 +73,8 @@ class PurchaseRequest(ModelSQL, ModelView):
         cls._error_messages.update({
                 'create_request': ('Purchase requests are only created '
                     'by the system.'),
+                'delete_purchase_line': ('You can not delete purchased '
+                    'request.'),
                 })
         cls._sql_constraints += [
             ('check_purchase_request_quantity', 'CHECK(quantity > 0)',
@@ -82,12 +84,14 @@ class PurchaseRequest(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         cursor = Transaction().cursor
+        sql_table = cls.__table__()
         super(PurchaseRequest, cls).__register__(module_name)
 
         # Migration from 2.0: empty order point origin is -1 instead of 0
-        cursor.execute('UPDATE "%s" '
-            'SET origin = %%s WHERE origin = %%s' % cls._table,
-            ('stock.order_point,-1', 'stock.order_point,0'))
+        cursor.execute(*sql_table.update(
+                columns=[sql_table.origin],
+                values=['stock.order_point,-1'],
+                where=sql_table.origin == 'stock.order_point,0'))
 
     def get_rec_name(self, name):
         if self.warehouse:
@@ -183,23 +187,23 @@ class PurchaseRequest(ModelSQL, ModelView):
         # compute requests
         new_requests = []
         cursor = Transaction().cursor
-        for dates, products in date2products.iteritems():
+        for dates, sub_products in date2products.iteritems():
             min_date, max_date = dates
-            for i in range(0, len(products), cursor.IN_MAX):
-                product_ids = [p.id for p in products[i:i + cursor.IN_MAX]]
+            for i in range(0, len(sub_products), cursor.IN_MAX):
+                product_ids = [p.id for p in sub_products[i:i + cursor.IN_MAX]]
                 with Transaction().set_context(forecast=True,
                         stock_date_end=min_date or datetime.date.max):
                     pbl = Product.products_by_location(warehouse_ids,
-                        product_ids, with_childs=True, skip_zero=False)
+                        product_ids, with_childs=True)
                 for warehouse_id in warehouse_ids:
-                    min_date_qties = dict((x, pbl.pop((warehouse_id, x)))
+                    min_date_qties = dict((x, pbl.pop((warehouse_id, x), 0))
                         for x in product_ids)
                     # Search for shortage between min-max
                     shortages = cls.get_shortage(warehouse_id, product_ids,
                         min_date, max_date, min_date_qties=min_date_qties,
                         order_points=product2ops)
 
-                    for product in products[i:i + cursor.IN_MAX]:
+                    for product in sub_products[i:i + cursor.IN_MAX]:
                         shortage_date, product_quantity = shortages[product.id]
                         if shortage_date is None or product_quantity is None:
                             continue
@@ -431,7 +435,7 @@ class PurchaseRequest(ModelSQL, ModelView):
             with Transaction().set_context(stock_date_start=current_date,
                     stock_date_end=current_date):
                 pbl = Product.products_by_location([location_id],
-                    product_ids, with_childs=True, skip_zero=False)
+                    product_ids, with_childs=True)
             for key, qty in pbl.iteritems():
                 _, product_id = key
                 current_qties[product_id] += qty
@@ -450,6 +454,12 @@ class PurchaseRequest(ModelSQL, ModelView):
                     cls.raise_user_error('create_request')
         return super(PurchaseRequest, cls).create(vlist)
 
+    @classmethod
+    def delete(cls, requests):
+        if any(r.purchase_line for r in requests):
+            cls.raise_user_error('delete_purchase_line')
+        super(PurchaseRequest, cls).delete(requests)
+
 
 class CreatePurchaseRequestStart(ModelView):
     'Create Purchase Request'
@@ -457,7 +467,7 @@ class CreatePurchaseRequestStart(ModelView):
 
 
 class CreatePurchaseRequest(Wizard):
-    'Create Purchase Request'
+    'Create Purchase Requests'
     __name__ = 'purchase.request.create'
     start = StateView('purchase.request.create.start',
         'stock_supply.purchase_request_create_start_view_form', [
@@ -466,8 +476,28 @@ class CreatePurchaseRequest(Wizard):
             ])
     create_ = StateAction('stock_supply.act_purchase_request_form')
 
+    @classmethod
+    def __setup__(cls):
+        super(CreatePurchaseRequest, cls).__setup__()
+        cls._error_messages.update({
+                'late_supplier_moves': ('There are some late supplier moves, '
+                    'are you sure to ignore them?'),
+                })
+
     def do_create_(self, action):
-        PurchaseRequest = Pool().get('purchase.request')
+        pool = Pool()
+        PurchaseRequest = pool.get('purchase.request')
+        Move = pool.get('stock.move')
+        Date = pool.get('ir.date')
+        today = Date.today()
+        if Move.search([
+                    ('from_location.type', '=', 'supplier'),
+                    ('to_location.type', '=', 'storage'),
+                    ('state', '=', 'draft'),
+                    ('planned_date', '<', today),
+                    ], order=[]):
+            self.raise_user_warning('%s@%s' % (self.__name__, today),
+                'late_supplier_moves')
         PurchaseRequest.generate_requests()
         return action, {}
 
